@@ -25,7 +25,7 @@
 BookView::BookView(QWidget *parent):
     QWebView(parent), contentIndex(-1), mBook(0),
     restorePositionAfterLoad(false), positionAfterLoad(0), loaded(false),
-    contentsHeight(0), scrollerMonitor(-1)
+    contentsHeight(0)
 {
     Trace t("BookView::BookView");
     settings()->setAttribute(QWebSettings::AutoLoadImages, true);
@@ -79,6 +79,7 @@ BookView::BookView(QWidget *parent):
     setBook(0);
 
 #ifdef Q_WS_MAEMO_5
+    scrollerMonitor = 0;
     scroller = property("kineticScroller").value<QAbstractKineticScroller *>();
 #endif
 }
@@ -105,7 +106,10 @@ void BookView::loadContent(int index)
     else {
         loaded = false;
         emit partLoadStart(index);
-        load(QUrl(mBook->rootPath() + "/" + contentFile));
+        QUrl u = QUrl::fromLocalFile(QDir(mBook->rootPath()).
+                                     absoluteFilePath(contentFile));
+        qDebug() << "Loading" << u;
+        load(u);
     }
     contentIndex = index;
 }
@@ -250,7 +254,7 @@ void BookView::paintEvent(QPaintEvent *e)
             continue;
         }
         int height = contentsHeight;
-        int bookmarkPos = (qreal)height * (qreal)b.pos;
+        int bookmarkPos = (int)((qreal)height * (qreal)b.pos);
         painter.drawPixmap(2, bookmarkPos - scrollPos.y(), bookmarkPixmap);
     }
 }
@@ -260,8 +264,12 @@ void BookView::mousePressEvent(QMouseEvent *e)
     QWebView::mousePressEvent(e);
 #ifdef Q_WS_MAEMO_5
     // Start monitoring kinetic scroll
+    if (scrollerMonitor) {
+        killTimer(scrollerMonitor);
+        scrollerMonitor = 0;
+    }
     if (scroller) {
-        scrollerMonitor = startTimer(250);
+        scrollerMonitor = startTimer(500);
     }
 #else
     // Handle mouse presses on the scroll bar
@@ -304,6 +312,9 @@ bool BookView::eventFilter(QObject *o, QEvent *e)
         if (e->type() == QEvent::Resize) {
             qDebug() << "BookView::eventFilter QEvent::Resize to"
                     << page()->mainFrame()->contentsSize().height();
+        } else if (e->type() == QEvent::Timer) {
+            qDebug() << "BookView::eventFilter" << "QEvent::Timer"
+                    << ((QTimerEvent *)e)->timerId();
         } else {
             qDebug() << "BookView::eventFilter" << Trace::event(e->type());
         }
@@ -367,7 +378,7 @@ void BookView::enterEvent(QEvent *e)
 
 void BookView::goToPosition(qreal position)
 {
-    int scrollPos = (qreal)contentsHeight * position;
+    int scrollPos = (int)((qreal)contentsHeight * position);
     page()->mainFrame()->setScrollPosition(QPoint(0, scrollPos));
     // FIXME: update();
     qDebug() << "BookView::goToPosition: To" << scrollPos << "("
@@ -385,8 +396,8 @@ void BookView::showProgress()
 
 void BookView::timerEvent(QTimerEvent *e)
 {
-    if (e->timerId() == scrollerMonitor) {
 #ifdef Q_WS_MAEMO_5
+    if (e->timerId() == scrollerMonitor) {
         if (scroller &&
             ((scroller->state() == QAbstractKineticScroller::AutoScrolling) ||
              (scroller->state() == QAbstractKineticScroller::Pushing))) {
@@ -394,8 +405,10 @@ void BookView::timerEvent(QTimerEvent *e)
         } else {
             killTimer(scrollerMonitor);
         }
-#endif // Q_WS_MAEMO_5
     }
+#else
+    Q_UNUSED(e);
+#endif // Q_WS_MAEMO_5
 }
 
 void BookView::keyPressEvent(QKeyEvent* event)
