@@ -85,7 +85,6 @@ void Library::load()
     }
     QString currentPath = settings.value("lib/nowreading").toString();
     mNowReading = find(currentPath);
-    mFolders = settings.value("lib/folders").toStringList();
 }
 
 void Library::save()
@@ -99,7 +98,6 @@ void Library::save()
     Book *currentBook = book(mNowReading);
     settings.setValue("lib/nowreading",
                       currentBook? currentBook->path(): QString());
-    settings.setValue("lib/folders", mFolders);
 }
 
 bool Library::add(const QString &path)
@@ -110,7 +108,7 @@ bool Library::add(const QString &path)
         return false;
     }
     if (find(path).isValid()) {
-        t.trace("Book already exists in library");
+        qDebug() << "Book already exists in library";
         return false;
     }
     int size = mBooks.size();
@@ -209,34 +207,3 @@ QStringList Library::bookPaths()
     }
     return ret;
 }
-
-QStringList Library::folders() const
-{
-    return mFolders;
-}
-
-bool Library::addFolder(const QString &folder)
-{
-    if (!mFolders.contains(folder)) {
-        mFolders.append(folder);
-        save();
-        return true;
-    } else {
-        return false;
-    }
-}
-
-bool Library::removeFolder(const QString &folder)
-{
-    if (mFolders.contains(folder)) {
-        mFolders.removeOne(folder);
-        save();
-        return true;
-    } else {
-        return false;
-    }
-}
-
-void Library::scanFolders()
-{
-}
