@@ -30,7 +30,12 @@ AdopterWindow::AdopterWindow(QWidget *parent):
     frame->setLayout(layout);
     setCentralWidget(frame);
 
-#ifndef Q_OS_SYMBIAN
+#ifdef Q_OS_SYMBIAN
+    QAction *closeAction = new QAction(parent? tr("Back"): tr("Exit"), this);
+    closeAction->setSoftKeyRole(QAction::NegativeSoftKey);
+    connect(closeAction, SIGNAL(triggered()), this, SLOT(close()));
+    QMainWindow::addAction(closeAction);
+#else
     // Tool bar
     setUnifiedTitleAndToolBarOnMac(true);
     toolBar = addToolBar("controls");
@@ -116,6 +121,9 @@ void AdopterWindow::doGrabZoomKeys(bool grab)
 void AdopterWindow::show()
 {
 #ifdef Q_OS_SYMBIAN
+    foreach (QWidget *w, QApplication::allWidgets()) {
+        w->setContextMenuPolicy(Qt::NoContextMenu);
+    }
     showMaximized();
 #else
     QMainWindow::show();
